DatabaseCore class abstract

Unified async interface for all database backends.

Each platform (native sqlite3, sqflite_ffi_web, gRPC) implements this interface to normalize access behind a single type.

Constructors

DatabaseCore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
execute(String sql, List<Object?> params) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(String sql, List<Object?> params) Future<List<Map<String, dynamic>>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited