HttpHelper class

Constructors

HttpHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(String url, Map<String, String?>? params, {String? method, Object? body, Map<String, String> additionalHeaders = const {}, dynamic isPushOrPull = false, SyncController? syncController}) Future
Return a MAP from the downloaded JSON or throws an Exception
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bearerAuthenticationHeader({required String token}) Map<String, String>
Add the Bearer Authentication header
simpleAuthenticationHeader({required String username, required String password}) Map<String, String>
Return the Simple Authentication header