SyncDetails class

Constructors

SyncDetails({required String clientid, String? name, required String useremail, required String userpassword, required DateTime lastsync, String? accessToken, String? refreshToken, DateTime? accessTokenExpiration})
SyncDetails.fromDB(Map row)
SyncDetails.fromMap(Map<String, dynamic> json)

Properties

accessToken String?
getter/setter pair
accessTokenExpiration DateTime?
getter/setter pair
clientid String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastsync DateTime
getter/setter pair
name String?
getter/setter pair
refreshToken String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useremail String
getter/setter pair
userpassword String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

tableName → const String