SyncProgress class

Constructors

SyncProgress({required SyncStatus status, required String message, int? processedItems, int? totalItems, String? error})

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
processedItems int?
final
progress double?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status SyncStatus
final
totalItems int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited