sync_client library
Sync Client Library
Main classes are
- SQLiteWrapperSync - an extension to the SQLiteWrapperCore library some methods to enable sync see
- SyncRepository
- TableInfos
Classes
- DatabaseCore
- Unified async interface for all database backends.
- DatabaseInfo
- Databases
-
Manages multiple named database connections.
Maps
dbNamestrings to DatabaseCore instances. - EncryptHelper
- Allow to encrypt/decrypt data before encodingKey MUST be set before using the class
- HttpHelper
- SQLiteWrapperBase
- SQLiteWrapperCore
- SQLiteWrapperSync
- SQLiteWrapperSyncGRPC
- You can use this class to sync from a GRPC SQLiteWrapper instance that uses a remote sqlite db as a local one
- SyncDetails
- SyncProgress
- SyncRepository
- TableInfo
Mixins
- SQLiteWrapperSyncMixin
- Use the mixin like this class MyDatabase extends SQLiteWrapperBase with SQLiteWrapperSyncMixin {
Constants
- defaultDBName → const String
- inMemoryDatabasePath → const String
- kChunkSize → const int
- kMaxDataToSendAtOnce → const int
- kMaxRetries → const int
- kSupportChunkedUpload → const bool
-
systemTables
→ const List<
String> - TABLES IGNORED IN SYNC OPERATIONS
Properties
- dio → Dio
-
final
- httpHelper → HttpHelper
-
final
Functions
-
getInstance(
) → SQLiteWrapperBase - Factory to get the current platform instance of SQLiteWrapperBase.
-
isRunningOnWeb(
) → bool
Typedefs
Exceptions / Errors
- ConnectionRefusedException
- CustomHttpException
- SyncException
- Define a sync exception