SyncRepository class
Methods
changePassword ({required String email , required String password , required String pin , required String dbName })
→ Future <void >
Change the password passing the PIN retrieved from the email received
deleteSyncDetails ({required String dbName })
→ Future <void >
Reset syncDetails usually when both tokens are invalid
dispose ()
→ void
forgottenPassword ({required String email })
→ Future <void >
Start a forgotten password request
the server sends a mail to the email address
with a PIN that must be used set the new password
using the changePassword method
getSyncDetails ({required String dbName })
→ Future <SyncDetails ? >
Get the current SyncDetails or null if sync is not yet configured
isConfigured ({required String dbName })
→ Future <bool >
Verifica se è configurata la sincronizzazione
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register ({required String ? name , required String email , required String password , required String deviceInfo , required bool newRegistration , required String language , required String secretKey , required String dbName })
→ Future <void >
Register the User and the Client
(only the Client if newRegistration is false)
and store the credentials in the DB
resetDB ({required String dbName })
→ Future <void >
Reset the table data for account and sync data
sync ({required String dbName })
→ Future <void >
Sync the data by performing two API calls
toString ()
→ String
A string representation of this object.
inherited
unregister ({required String email , required String password , required String clientId , required String dbName , dynamic deleteRemoteData = false })
→ Future <void >
Unregister the client, optionally deleting ALL the data
related to this user if the deleteRemoteData is set to true