TableInfo class
Properties
aliasesFields
↔ Map <String , String >
Boolesn Fields are transcoded from integers
A list of external keys mapped on different tables
A Map of aliases that should be transcoded on the server side (@deprecated?)
getter/setter pair
binaryFields
→ List <String >
Binary Fields should be encoded as base64
final
encryptedFields
→ List <String >
Encrypted Fields should be encoded as base64
final
hashCode
→ int
The hash code for this object.
no setter inherited
includeBinaryField
→ bool Function(String fieldName , Map <String , dynamic > rowData ) ?
Optional per-row callback to decide whether a binary field should be encoded
and included in the sync payload.
final
keyField
→ String
The table key field
final
rowFilter
→ String ?
Optional SQL WHERE clause (without the WHERE keyword) to filter which rows
are eligible for sync logging.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited